# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](http://keepachangelog.com/en/1.0.0/)
and this project adheres to [Semantic Versioning](http://semver.org/spec/v2.0.0.html).

## [Unreleased]
## [0.8] - 2024-03-16
### Added
- `feature_request.yml` template
- `config.yml` for issue template
- Discord badge
- Console scripts entry point
### Changed
- Bug report template modified
- `README.md` modified
- `Python 3.10` added to `test.yml`
- `Python 3.11` added to `test.yml`
- `Python 3.12` added to `test.yml`
- Logo updated
- `AUTHORS.md` updated
- Test system modified
- Setup system modified
- Docstrings modified
- `check_update` function modified
## [0.7] - 2021-08-18
### Added
- Chakraborty model
### Changed
- Test system modified
- Import section updated
## [0.6] - 2020-03-16
### Added
- `__version__` variable
### Changed
- Test system modified
- `dev-requirements.txt` modified
- `requirements.txt` modified
- Logo updated
- Icon updated
- `ISSUE_TEMPLATE.md` updated
- `setup.py` modified
- `README.md` modified
- `build_exe.bat` modified
- `build_unix.sh` modified
## [0.5] - 2019-10-28
### Added
- `version_check.py`
- `CODE_OF_CONDUCT.md`
- `ISSUE_TEMPLATE.md`
- `PULL_REQUEST_TEMPLATE.md`
- `build_exe.bat`
- `build_unix.sh`
- `GOPEM.iss`
- Check update button
- Save plot button
- Report generating controller
- Console print controller
- PyPI package
### Changed
- `CONTRIBUTING.md` modified
- `README.md` modified
- Test system modified
- Menu bug in `Windows` fixed
- Padulles-Amphlett model default test case bug fixed
- Docstrings modified
- Report default location bug fixed
- Icon bug fixed
## [0.1] - 2018-09-10
### Added
- GUI and plotter
- Use same test data as `OPEM` lib
- Documents and README


[Unreleased]: https://github.com/ECSIM/gopem/compare/v0.8...develop
[0.8]: https://github.com/ECSIM/gopem/compare/v0.7...v0.8
[0.7]: https://github.com/ECSIM/gopem/compare/v0.6...v0.7
[0.6]: https://github.com/ECSIM/gopem/compare/v0.5...v0.6
[0.5]: https://github.com/ECSIM/gopem/compare/v0.1...v0.5
[0.1]: https://github.com/ECSIM/gopem/compare/0f35fc9...v0.1
